debug(7 | 34);

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

import java.net.*;
import java.io.*;

sub bytes {
	local('$temp');
	$temp = $1;

	if ($temp < 1024) {
		return round($temp, 1) . "b";
	}

	$temp /= 1024.0;
	if ($temp < 1024) {
		return round($temp, 1) . "kb";
	}

	$temp /= 1024.0;
	return round($temp, 1) . "mb";
}

# SHA-256 hashes of our various SSL certificates!
global('%fingerprint');
%fingerprint["verify.cobaltstrike.com"] = @(

		# Valid: May 17, 2021 through May 25, 2022
		"3d778be9c600a481b69fb067312e1883f8eadf3b88337f8153085e79f98c94ec",

		# Valid: Dec 2, 2019 through December 6, 2021
		"0ef72eaf384c12c486d1218c2ada63eda2758a56519ed03055d9d12042e59987");

%fingerprint["download.cobaltstrike.com"]    = @(

		# Valid: Jul 13, 2021 through Jul 18, 2022
		"201ede2cfd6681aa6471f6f55dc41eccfb5296e200cb799d83188311be6f0fb6",

		# Valid: Apr 10, 2021 through Apr 9, 2022
		"09d4042ff1642fcac5c592ad5eb2e8eec0df6ae19ccd3c4808f391484df7a879");

%fingerprint["www.cobaltstrike.com"]    = @(
		# Valid: May 17, 2021 through May 25, 2022
		"07271850765fa6b48df03ce04e013479b38d600a60f4b13d84ed28fbe927aaec",

		# Valid: Dec 3, 2019 through December 6, 2021
		"d7d5d6e5f65b22e6661340ec71dba91d651b67179d26b781e8074a5b94ec7301");

sub get {
	local('$fetch $handle $read $data $buffer $report $finger $host $expected');
	$fetch = [new updater.UpdaterFetch: $1];
	[$fetch go];
	$host  = [$fetch host];
	
	$expected = %fingerprint[$host];

	$finger = [updater.Main checkServerTrusted: [$fetch getServerCertificates]];
	
	if ($finger !in $expected) {
		error("SSL certificate verification for $host failed.\n    Observed SHA-256 fingerprint: $finger $+ \n    Expected SHA-256 fingerprint: " . $expected[-1] . "\n\n    Is someone performing SSL intercept? Don't trust this update unless\n    you know why this certificate fingerprint doesn't match.\n");
		query("Would you like to continue with this update?");
		if (ask() is $null) {
			[System exit: 0];
		}
	}

	$handle = [SleepUtils getIOHandle: [$fetch getInputStream], $null];

	if ($2) {
		# download the file in chunks and report each successful chunk.
		$buffer = allocate(1024 * 1024 * 20);
		$read = 0;
		$report = ticks();
		while $data (readb($handle, 1024 * 512)) {
			$read += strlen($data);
			writeb($buffer, $data);

			if ((ticks() - $report) > 5000) {
				println("Downloaded " . bytes($read));
				$report = ticks();
			}

			sleep(rand() * 1000);
		}
		println("Read " . bytes($read));
		closef($buffer);
		$data = readb($buffer, -1);
		closef($buffer);
		return $data;
	}
	else {
		$data = readb($handle, -1);
		closef($handle);
		return $data;
	}
}

inline finish {
	return;
}

sub ask {
	local('$answer');
	while (1) {
		print("(yes/no): ");
		$answer = [(readln() . "") trim];
		if (lc($answer) eq "yes") {
			return 1;
		}
		else if (lc($answer) eq "no") {
			return $null;
		}
	}
}

sub error {
	[updater.Main print_error: $1];
}

sub report {
	[updater.Main print_good: $1];
}

sub info {
	[updater.Main print_info: $1];
}

sub query {
	[updater.Main print_query: $1];
}

sub verifyProcess {
	local('$handle $check $content $temp $hash $description $ex');
	try {

		info("Download latest hashes");

		$content = [get("https://verify.cobaltstrike.com/index.txt", $null) trim];
		$check = unpack("H*", digest($1, "SHA-256"))[0];

		foreach $temp (split("\n", $content)) {
			($hash, $description) = split("\\t+", $temp);
			if ($hash eq $check) {
				report("Verified $description $+ \n    SHA-256: $hash");
				return 1;
			}		
		}

		error("$check does not match known hash.");
		return $null;
	}
	catch $ex {
		error("Failed to download hashes from https://verify.cobaltstrike.com (" . [$ex toString] . ")");
		return $null;
	}
}

sub kash {
	local('$kash');
	$kash = [updater.Main kash];
	if ($kash is $null) {
		return "";
	}
	else {
		return unpack("H*", digest($kash, "MD5"))[0];
	}
}

sub updateProcess {
	local('$check $digest $handle $latest $license $url $data $file $kash');

	# announce the version
	report("Cobalt Strike Update (20210802)");

	# announce the certificate deprecation
	if (formatDate("yyMMdd") >= 220525) {
		error("This build of the Cobalt Strike Update program is now expired. This expiration is necessary to accommodate a planned change to the Cobalt Strike update infrastructure. The latest Cobalt Strike package has an updated updater. Please download the latest Cobalt Strike distribution at:\n\nhttps://download.cobaltstrike.com/download");
		finish();
	}

	# grab the kash
	$kash = kash();

	# retrieve the license information
	$file = getFileProper(systemProperties()["user.home"], ".cobaltstrike.license");
	if (!-exists $file) {
		error("I can not find your license key, please enter it now:");
		while (1) {
			$license = readln();
			$license = ["$license" trim];
			if ($license eq "") {
				query("Please enter another license key:");
			}
			else {
				$check = [get("https://download.cobaltstrike.com/update40?license= $+ $license $+ &kash= $+ $kash", $null) trim];
				sleep(1000);
				if ($check !ismatch 'Latest: ([a-zA-Z0-9]{32}) (https://.*)') {
					error($check);
					query("Please enter another license key:");
				}
				else {
					break;
				}
			}
		}
		
		# write out the license.
		$handle = openf("> $+ $file");
		println($handle, $license);
		closef($handle);
	}
	else {
		$handle = openf($file);
		$license = readln($handle);
		closef($handle);
	}

	# check that our binary is ok
	if (!-exists "cobaltstrike.jar") {
		error("I can not find cobaltstrike.jar. Aborting.");
		finish();
	}
	else if (!-canread "cobaltstrike.jar") {
		error("I can not read cobaltstrike.jar (permissions issue?). Aborting.");
		finish();
	}
	
	if (!-canwrite "cobaltstrike.jar") {
		error("I can not write to cobaltstrike.jar. Make sure it's not running. Aborting.");
		finish();
	}

	# digest our binary
	$handle = openf("cobaltstrike.jar");
	$digest = digest($handle, "MD5");
	skip($handle, lof("cobaltstrike.jar"));
	$digest = unpack("H*", digest($digest))[0];

	# check our license and get the latest hash for cobalt strike
	info("Checking for latest version");
	$check = [get("https://download.cobaltstrike.com/update40?license= $+ $license $+ &kash= $+ $kash", $null) trim];

	if ($check ismatch 'Latest: ([a-zA-Z0-9]{32}) (https://.*)') {
		($latest, $url) = matched();
		if ($latest eq $digest) {
			report("Your installation of Cobalt Strike is up to date!");
		}
		else {
			info("Downloading the latest version of Cobalt Strike");

			# update cobalt strike...
			$data = get($url, 1);

			# this is not for security. This is to prevent your MITM SSL device (when you give it permission,
			# I *do* pin SSL certs) from submitting cobaltstrike.jar to VirusTotal. It doesn't happen often
			# [because... most of you are awesome]--but it has happened and it *really* sucks for my efforts 
			# to limit distribution of this product to licensed/authorized users.
			report("Download complete. Unpacking Cobalt Strike program data.");
			$data = [updater.Main decrypt: $data, "aliens"];		

			report("Unpacked Cobalt Strike program data. Now verifying the download");
			$check = unpack("H*", digest($data, "MD5"))[0];

			if ($check eq $latest) {
				if (verifyProcess($data) is $null) {
					error("Verification Failed! [Don't trust this update!]");

					query("Would you like to continue with the update?");
					if (ask() is $null) {
						finish();
					}
				}

				# update our cobaltstrike.jar file
				info("Updating cobaltstrike.jar");
				[updater.Main writeToFile: [new java.io.File: "cobaltstrike.jar"], $data];
				report("SUCCESS! Updated cobaltstrike.jar");

				# update the releasenotes.txt file
				info("Download releasenotes.txt");
				$data = get("https://download.cobaltstrike.com/releasenotes.txt", $null);
				$handle = openf(">releasenotes.txt");
				writeb($handle, $data);
				closef($handle);

				report("Downloaded and updated releasenotes.txt. Be sure to read this file!");
			}
			else {
				error("I downloaded cobaltstrike.jar, but the hash doesn't match the expected value. Try again. If this problem continues, please contact cobalt.custops@helpsystems.com.");
			}
		}

		# refresh the 
		info("Refresh cobaltstrike.auth");
		$check = [get("https://download.cobaltstrike.com/authfile40?license= $+ $license", $null) trim];
		if ([$check startsWith: "SUCCESS "]) {
			$handle = openf(">cobaltstrike.auth");
			writeb($handle, [updater.Base64 decode: substr($check, 8)]);
			closef($handle);
			report("Refreshed your Cobalt Strike authorization file!");
		}
		else {
			error($check);
		}
	}
	else {
		error($check);
	}

	report("Done!");
	finish();
}

try {
	updateProcess();
}
catch $exception {
	error("Something in the update process failed:\n $+ $exception");
	printAll(getStackTrace());
}
